==> dscript-0.1.1.tar.gz: dscript-0.1.1/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os.path
import sys
sys.path[:0] = [os.path.dirname(os.path.abspath(__file__)) + "/../../"]
import dscript


# -- Project information -----------------------------------------------------

project = 'D-SCRIPT'
copyright = '2020, Samuel Sledzieski, Rohit Singh'
author = 'Samuel Sledzieski, Rohit Singh'

# The full version, including alpha/beta/rc tags
release = 'v1.0-beta'

master_doc = 'index'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.todo','sphinx.ext.viewcode','sphinx.ext.autodoc','sphinx.ext.mathjax']


# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']


# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
#html_theme = 'default'
html_theme = 'sphinx_rtd_theme'
# html_theme_options = {
#     'logo_only':  True,
# }
# html_logo = '_static/dscript_architecture1.png'

==> dscript-0.1.8a0.tar.gz: dscript-0.1.8a0/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os.path
import sys

sys.path[:0] = [os.path.dirname(os.path.abspath(__file__)) + "/../../"]
import dscript


# -- Project information -----------------------------------------------------

project = "D-SCRIPT"
copyright = "2020, Samuel Sledzieski, Rohit Singh"
author = "Samuel Sledzieski, Rohit Singh"

# The full version, including alpha/beta/rc tags
release = "v1.0-beta"

master_doc = "index"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.todo",
    "sphinx.ext.viewcode",
    "sphinx.ext.autodoc",
    "sphinx.ext.mathjax",
]


# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]


# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
# html_theme = 'default'
html_theme = "sphinx_rtd_theme"
# html_theme_options = {
#     'logo_only':  True,
# }
# html_logo = '_static/dscript_architecture1.png'
